@@ -2,23 +2,23 @@
 from __future__ import (absolute_import, division, print_function,
                         unicode_literals)
 import logging
-
-
-__version__ = '0.3.2'
-
+from pkg_resources import get_distribution
 
 # analog logger
 LOG = logging.getLogger('analog')
 LOG.addHandler(logging.NullHandler)
 
+from analog.analyzer import Analyzer, analyze  # noqa
+from analog.exceptions import (  # noqa
+    AnalogError, InvalidFormatExpressionError, MissingFormatError,
+    UnknownRendererError)
+from analog.formats import LogFormat  # noqa
+from analog.main import main  # noqa
+from analog.report import Report  # noqa
+from analog.renderers import Renderer  # noqa
 
-from analog.analyzer import Analyzer, analyze
-from analog.exceptions import (AnalogError, InvalidFormatExpressionError,
-                               MissingFormatError, UnknownRendererError)
-from analog.formats import LogFormat
-from analog.main import main
-from analog.report import Report
-from analog.renderers import Renderer
+
+__version__ = get_distribution('analog').version
 
 
 __all__ = (
